#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""


class IUnknown:
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | Role: All interfaces derive from IUnknown which replaces for UNIX the native
                | Microsoft(R) IUnknown interface. This interface supplies the three basic
                | methods QueryInterface, AddRef and Release to be COM (Microsoft(R) Component
                | Object Model) compliant. These methods cannot be used in a
                | macro.
                | 
                | Copyright © 1999-2011, Dassault Systèmes. All rights reserved.
    
    """

    def __init__(self):
        pass

    def __repr__(self):
        return f'IUnknown()'
